@@ -105,6 +105,12 @@ class IExampleConstructProps(typing_extensions.Protocol):
     @builtins.property
     @jsii.member(jsii_name="layerVersionName")
     def layer_version_name(self) -> builtins.str:
+        '''Debug log sampling rate.
+
+        Zero means all events.
+
+        :default: 'test'
+        '''
         ...
 
     @layer_version_name.setter
@@ -118,6 +124,12 @@ class _IExampleConstructPropsProxy:
     @builtins.property
     @jsii.member(jsii_name="layerVersionName")
     def layer_version_name(self) -> builtins.str:
+        '''Debug log sampling rate.
+
+        Zero means all events.
+
+        :default: 'test'
+        '''
         return typing.cast(builtins.str, jsii.get(self, "layerVersionName"))
 
     @layer_version_name.setter
